\name{tp_glob}
\alias{tp_glob}
\alias{tp2_glob}
\alias{tp_itglob}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Dimension Estimation via Translated Poisson Distributions }
\description{
Estimates the intrinsic dimension of a data set using models of translated
Poisson distributions. \code{tp} and \code{tp2} employs an approximation to avoid iteration
(see Haro el al. (2008)), \code{tp_it} does five iterations to get the result.
However, opposed to Haro et al. (2008) these functions uses distances between
data points in the whole data set instead of local dimension estimation.
}
\usage{
tp_glob(data, k, dnoise, sigma, n)
tp2_glob(data, k, dnoise, sigma, n)
tp_itglob(data, k, dnoise, sigma, n, init = 5)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{data set with each row describing a data point.}
  \item{k}{the number of distances between data points that should be used for
    dimension estimation.}
  \item{dnoise}{a function or a name of a function giving the transition density.}
  \item{sigma}{(estimated) standard deviation of the (isotropic) noise.}
  \item{n}{dimension of the noise.}
  \item{init}{initial value for iterative procedure.}
}
\details{
  \code{tp_glob} uses the same approximation as Haro et al. (2008) of a certain
  integral, \code{tp2_glob} multiplies the integrand with \code{r}, which guarantees
  that the integral converges. However, the approximation in \code{tp2_glob} does not
  result in error terms that are symmetric around \code{r} as in \code{tp_glob}. 
}
\value{
  A vector with two components:
  \item{de}{the dimension estimate.}
  \item{likelihood}{this is \code{NA} in the current implementation.}
}
\references{
  Haro, G., Randall, G. and Sapiro, G. (2008) Translated Poisson Mixture Model
  for Stratification Learning. \emph{Int. J. Comput. Vis.}, \bold{80}, 358-374.
}
\author{
Kerstin Johnsson, Lund University
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{tp}}, \code{\link{tp_loc}}
}
\examples{
require(manifgen)
data <- hball(1000, d = 7, n = 13, sd = 0.01)
tp_glob(data, 500, dnoiseGaussH, 0.01, 13)
tp_glob(data, 500, dnoiseNcChi, 0.01, 13)
tp2_glob(data, 500, dnoiseGaussH, 0.01, 13)
tp2_glob(data, 500, dnoiseNcChi, 0.01, 13)
tp_itglob(data, 500, dnoiseGaussH, 0.01, 13)
tp_itglob(data, 500, dnoiseNcChi, 0.01, 13)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
