\name{tp_loc}
\alias{tp_loc}
\alias{tp2_loc}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Local Dimension Estimation via Translated Poisson Distributions }
\description{
  Performs local dimension estimation of a neighborhood centered at the origin,
  using models of translated Poisson distributions.
}
\usage{
tp_loc(data, dnoise, sigma, n)
tp2_loc(data, dnoise, sigma, n)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{data set with each row describing a data point.}
  \item{dnoise}{a function or a name of a function giving the translation density.}
  \item{sigma}{(estimated) standard deviation of the (isotropic) noise.}
  \item{n}{dimension of the noise.}
}
\details{
  \code{tp_loc} uses the same approximation as Haro et al. (2008) of a certain
  integral, \code{tp2_loc} multiplies the integrand with \code{r}, which guarantees
  that the integral converges. However, the approximation in \code{tp2_loc} does not
  result in error terms that are symmetric around \code{r} as in \code{tp_loc}. 
}
\value{
  A vector with two components:
  \item{de}{the dimension estimate.}
  \item{likelihood}{this is \code{NA} in the current implementation.}
}
\references{
  Haro, G., Randall, G. and Sapiro, G. (2008) Translated Poisson Mixture Model
  for Stratification Learning. \emph{Int. J. Comput. Vis.}, \bold{80}, 358-374.
}
\author{
Kerstin Johnsson, Lund University
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{tp}}, \code{\link{tp_glob}}
}
\examples{
require(manifgen)
data <- cuthplane(50, d = 7, n = 13, sd = 0.01)
tp_loc(data, dnoiseNcChi, 0.1, 3)
tp_loc(data, dnoiseGaussH, 0.1, 3)
tp2_loc(data, dnoiseNcChi, 0.1, 3)
tp2_loc(data, dnoiseGaussH, 0.1, 3)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
